==> webpack-omit-js-for-css-plugin-2.0.0.tgz: package/README.md <==
[![npm version](https://img.shields.io/npm/v/webpack-omit-js-for-css-plugin.svg)](https://www.npmjs.com/package/webpack-omit-js-for-css-plugin) [![Build Status](https://travis-ci.org/jsilvax/webpack-omit-js-for-css-plugin.svg?branch=master)](https://travis-ci.org/jsilvax/webpack-omit-js-for-css-plugin) [![Coverage Status](https://coveralls.io/repos/github/jsilvax/webpack-omit-js-for-css-plugin/badge.svg)](https://coveralls.io/github/jsilvax/webpack-omit-js-for-css-plugin)

# Webpack Omit JS for CSS Plugin

This plugin will omit bundled JS files for dependencies that are exclusively CSS, which become obsolete once extract-text-plugin extracts inlined CSS into its own .css file

## Rationale

In certain cases, you may want to organize some of your CSS dependencies into single files or entry arrays within Webpack. Even though Extract-text-plugin extracts CSS into its own .css file, Webpack will still generate a js file that will never be needed. This plugin will omit these types of files before Webpack begins its emitting step, so that you don't have to manually remove them. This plugin is especially useful for Webpack bundles that use a hash in the filename, as these change on every compilation.

Example as a file
```js
// styles.js
require('a.css');
require('b.css');

// webpack.config.js
module.exports = {
	entry: {
		'common.styles' : 'styles.js'
	}
}
```
> :warning: CSS dependencies in a JS file are 1 level deep. It will not recursively check for dependencies, that are exclusively CSS, when requiring additional JS files.

Example as an array
```js
module.exports = {
	entry: {
		'common.styles' : [
			'a.css',
			'b.css'
		]
	}
}
```
In both examples Webpack would output:
`` common.styles.js (Not Needed)``
``common.styles.css``


## Installation
```bash
// For Webpack v3.x
npm install --save-dev webpack-omit-js-for-css-plugin

// For Webpack v2.x
npm install --save-dev webpack-omit-js-for-css-plugin@1.0.2
```
## Usage

```js
const OmitJSforCSSPlugin = require("webpack-omit-js-for-css-plugin");

module.exports = {
	plugins: [
		new OmitJSforCSSPlugin()
	]
}
```
> Note: [ExtractTextPlugin](https://github.com/webpack-contrib/extract-text-webpack-plugin "ExtractTextPlugin") is a Peer Dependency. You will need to configure that as you normally would in your webpack.config.js

## Options
```js
new OmitJSforCSSPlugin(options: object)
```
|Name|Type|Default|Description|
|:--:|:--:|:-----:|:----------|
|**`preview`**|`{Boolean}`|false|Will display a preview of the files that are to be omitted in the console (Will not actually omit)|
|**`cacheOnWatch`**|`{Boolean}`|false|Whether it should cache the JS filenames that should be omitted, on watch|
|**`verbose`**|`{Boolean}`|false|Whether it should display which files will be omitted to the console|

## :fire: Additional Notes :fire:
While this plugin supports caching the omissible files on watch, it's not ideal to use this plugin during Development. It's highly recommended you only include this plugin when you're building for production.

==> webpack-omit-js-for-css-plugin-3.1.0.tgz: package/README.md <==
[![npm version](https://img.shields.io/npm/v/webpack-omit-js-for-css-plugin.svg)](https://www.npmjs.com/package/webpack-omit-js-for-css-plugin) [![Build Status](https://travis-ci.org/jsilvax/webpack-omit-js-for-css-plugin.svg?branch=master)](https://travis-ci.org/jsilvax/webpack-omit-js-for-css-plugin) [![Coverage Status](https://coveralls.io/repos/github/jsilvax/webpack-omit-js-for-css-plugin/badge.svg)](https://coveralls.io/github/jsilvax/webpack-omit-js-for-css-plugin)

# Webpack Omit JS for CSS Plugin

This plugin will omit bundled JS files for dependencies that are exclusively CSS, which become obsolete once mini-css-extract-plugin extracts inlined CSS into its own .css file

## Rationale

In certain cases, you may want to organize some of your CSS dependencies into single files or entry arrays within Webpack. Even though mini-css-extract-plugin extracts CSS into its own .css file, Webpack will still generate a js file that will never be needed. This plugin will omit these types of files before Webpack begins its emitting step, so that you don't have to manually remove them. This plugin is especially useful for Webpack bundles that use a hash in the filename, as these change on every compilation.

Example as a file
```js
// styles.js
require('a.css');
require('b.css');

// webpack.config.js
module.exports = {
	entry: {
		'common.styles' : 'styles.js'
	}
}
```
> :warning: CSS dependencies in a JS file are 1 level deep. It will not recursively check for dependencies, that are exclusively CSS, when requiring additional JS files.

Example as an array
```js
module.exports = {
	entry: {
		'common.styles' : [
			'a.css',
			'b.css'
		]
	}
}
```
In both examples Webpack would output:
`` common.styles.js (Not Needed)``
``common.styles.css``


## Installation
```bash
// For Webpack v4.x
npm install --save-dev webpack-omit-js-for-css-plugin

// For Webpack v3.x
npm install --save-dev webpack-omit-js-for-css-plugin@2.0.0
```
## Usage

```js
const OmitJSforCSSPlugin = require("webpack-omit-js-for-css-plugin");

module.exports = {
	plugins: [
		new OmitJSforCSSPlugin()
	]
}
```
> Note: [MiniCssExtractPlugin](https://github.com/webpack-contrib/mini-css-extract-plugin "MiniCssExtractPlugin") is a Peer Dependency. You will need to configure that as you normally would in your webpack.config.js

## Options
```js
new OmitJSforCSSPlugin(options: object)
```
|Name|Type|Default|Description|
|:--:|:--:|:-----:|:----------|
|**`preview`**|`{Boolean}`|false|Will display a preview of the files that are to be omitted in the console (Will not actually omit)|
|**`verbose`**|`{Boolean}`|false|Whether it should display which files will be omitted to the console|

## :fire: Additional Notes :fire:
It is highly recommended you only include this plugin when you're building for production.
